@@ -9,7 +9,6 @@ Simple command-line interface to bugzilla to allow:
 Requirements
 ------------
 - Python 3.3 or later
-- setuptools
 
 Classes
 -------
@@ -25,12 +24,6 @@ import sys
 import textwrap
 import xmlrpc.client
 
-try:
-    import readline
-except ImportError:
-    pass
-
-
 from bugz.cli_argparser import make_arg_parser
 from bugz.configfile import load_config
 from bugz.settings import Settings
@@ -59,28 +52,29 @@ def check_bugz_token():
     print('This decision was made because Bugzilla is deprecating tokens.')
 
 
-def login(settings):
+def check_auth(settings):
     """Authenticate a session.
     """
+    if settings.skip_auth:
+        for x in ['key', 'user', 'password']:
+            if hasattr(settings, x):
+                delattr(settings, x)
+    elif settings.interactive:
+        # prompt for username if we were not supplied with it
+        if not hasattr(settings, 'user'):
+            log_info('No username given.')
+            settings.user = input('Username: ')
 
-    if settings.skip_auth or hasattr(settings, 'key'):
-        return
-
-    # prompt for username if we were not supplied with it
-    if not hasattr(settings, 'user'):
-        log_info('No username given.')
-        settings.user = input('Username: ')
-
-    # prompt for password if we were not supplied with it
-    if not hasattr(settings, 'password'):
-        if not hasattr(settings, 'passwordcmd'):
-            log_info('No password given.')
-            settings.password = getpass.getpass()
-        else:
-            process = subprocess.Popen(settings.passwordcmd, shell=True,
-                                       stdout=subprocess.PIPE)
-            password, _ = process.communicate()
-            settings.password = password.splitlines()[0]
+        # prompt for password if we were not supplied with it
+        if not hasattr(settings, 'password'):
+            if not hasattr(settings, 'passwordcmd'):
+                log_info('No password given.')
+                settings.password = getpass.getpass()
+            else:
+                process = subprocess.Popen(settings.passwordcmd, shell=True,
+                        stdout=subprocess.PIPE)
+                password, _ = process.communicate()
+                settings.password = password.splitlines()[0]
 
 
 def list_bugs(buglist, settings):
@@ -354,7 +348,7 @@ def attach(settings):
     params['comment'] = comment
     if is_patch is not None:
         params['is_patch'] = is_patch
-    login(settings)
+    check_auth(settings)
     result = settings.call_bz(settings.bz.Bug.add_attachment, params)
     attachid = result['ids'][0]
     log_info('{0} ({1}) has been attached to bug {2}'.format(
@@ -368,7 +362,7 @@ def attachment(settings):
     params = {}
     params['attachment_ids'] = [settings.attachid]
 
-    login(settings)
+    check_auth(settings)
 
     result = settings.call_bz(settings.bz.Bug.attachments, params)
     result = result['attachments'][settings.attachid]
@@ -393,7 +387,7 @@ def attachment(settings):
 
 def get(settings):
     """ Fetch bug details given the bug id """
-    login(settings)
+    check_auth(settings)
 
     log_info('Getting bug %s ..' % settings.bugid)
     params = {'ids': [settings.bugid]}
@@ -523,7 +517,7 @@ def modify(settings):
 
     if len(params) < 2:
         raise BugzError('No changes were specified')
-    login(settings)
+    check_auth(settings)
     result = settings.call_bz(settings.bz.Bug.update, params)
     for bug in result['bugs']:
         changes = bug['changes']
@@ -538,15 +532,15 @@ def modify(settings):
 
 def post(settings):
     """Post a new bug"""
-    login(settings)
+    check_auth(settings)
     # load description from file if possible
     if hasattr(settings, 'description_from'):
         try:
-                if settings.description_from == '-':
-                    settings.description = sys.stdin.read()
-                else:
-                    settings.description = \
-                        open(settings.description_from, 'r').read()
+            if settings.description_from == '-':
+                settings.description = sys.stdin.read()
+            else:
+                settings.description = \
+                    open(settings.description_from, 'r').read()
         except IOError as error:
             raise BugzError('Unable to read from file: %s: %s' %
                             (settings.description_from, error))
@@ -648,7 +642,7 @@ the keywords given on the title (or the body if specified).
     valid_keys = ['alias', 'assigned_to', 'component', 'creator',
                   'limit', 'offset', 'op_sys', 'platform',
                   'priority', 'product', 'resolution', 'severity',
-                  'version', 'whiteboard']
+                  'version', 'whiteboard', 'cc']
 
     params = {}
     d = vars(settings)
@@ -668,7 +662,7 @@ the keywords given on the title (or the body if specified).
     for key in params:
         log_info('   {0:<20} = {1}'.format(key, params[key]))
 
-    login(settings)
+    check_auth(settings)
 
     result = settings.call_bz(settings.bz.Bug.search, params)['bugs']
 
@@ -714,4 +708,6 @@ def main():
 
 
 if __name__ == "__main__":
+    if sys.version_info >= (3, 7):
+        sys.stdout.reconfigure(encoding='utf-8')
     main()
