@@ -2,7 +2,7 @@ import argparse
 
 import bugz.cli
 
-from bugz.definitions import __version__
+from bugz import __version__
 
 
 def make_arg_parser():
@@ -39,6 +39,10 @@ def make_arg_parser():
     parser.add_argument('--insecure',
                         action='store_true',
                         help='do not verify ssl certificate')
+    parser.add_argument('--interactive',
+                        action='store_true',
+                        help='prompt for username and password if '
+                        'they are not specified')
     parser.add_argument('--version',
                         action='version',
                         help='show program version and exit',
@@ -211,9 +215,9 @@ def make_arg_parser():
     modify_parser.add_argument('-U', '--url',
                                help='set URL field of bug')
     modify_parser.add_argument('-v', '--version',
-                               help='set the version for this bug'),
+                               help='set the version for this bug')
     modify_parser.add_argument('-w', '--whiteboard',
-                               help='set Status whiteboard'),
+                               help='set Status whiteboard')
     modify_parser.add_argument('--fixed',
                                action='store_true',
                                help='mark bug as RESOLVED, FIXED')
@@ -276,6 +280,8 @@ def make_arg_parser():
                                help='The unique alias for this bug')
     search_parser.add_argument('-a', '--assigned-to',
                                help='email the bug is assigned to')
+    search_parser.add_argument('--cc',
+                               help='email in the CC list for the bug')
     search_parser.add_argument('-C', '--component',
                                action='append',
                                help='restrict by component (1 or more)')
